@@ -458,7 +458,7 @@ def get_available_sketch_widget(sb, allow_multiple=True):
             options=available_sketch_ids,
             value=None,
             rows=10,
-            description="Sketch IDs: ",
+            description="Sketch ID: ",
             disabled=False,
             layout=widgets.Layout(width="50%"),
             style=dict(description_width="initial"),
@@ -476,7 +476,7 @@ def get_available_dataset_widget(sb, only_labeled=False):
         options=available_dataset_ids,
         value=None,
         rows=5,
-        description="Dataset IDs: ",
+        description="Dataset ID: ",
         disabled=False,
         layout=widgets.Layout(width="50%"),
         style=dict(description_width="initial"),
